// 模拟导入相关模块，需要根据实际情况调整
import { RestClient } from './RestClient'; // 假设 RestClient 定义在此路径
import { ServiceSettings } from './ServiceSettings'; // 假设 ServiceSettings 定义在此路径
import { LoginUserInfo } from './LoginUserInfo'; // 假设 LoginUserInfo 定义在此路径
import { GetTokenReq, TokenResult, ElementInfoResult, ApplyInfoReq, RmAuthResult, FlawTradeListResult, AuthHistoryInfoResult, FlawInfoReq } from './AuthEntity'; // 假设这些实体定义在此路径
import { RSAUtil } from './RSAUtil'; // 假设 RSAUtil 定义在此路径
import { PlatformLogger } from './PlatformLogger'; // 假设 PlatformLogger 定义在此路径

export class AuthHandle {
    private static restClient: RestClient = new RestClient(ServiceSettings.AuthServiceUri);
    private static authSystemName: string = ServiceSettings.AuthSystemName;
    private static authSystemSecret: string = ServiceSettings.AuthSystemSecret;
    private static tellerNo: string = LoginUserInfo.TellerNo.trim();
    private static tellerName: string = LoginUserInfo.TellerName.trim();
    private static threadTimer: NodeJS.Timer | null = null;

    private static authToken: string | null = null;

    public static get AuthToken(): string {
        if (this.authToken === null) {
            this.authToken = this.GetToken();
            this.threadTimer = setInterval(() => this.TimerUp(null), 300000);
        }
        return this.authToken;
    }

    private static TimerUp(value: any): void {
        try {
            this.authToken = this.GetToken();
        } catch (e) {
            if (e instanceof Error) {
                PlatformLogger.TradeErrorInfo('GetToken Exception', e);
            }
        }
    }

    private static GetToken(): string {
        const req: GetTokenReq = new GetTokenReq();
        req.sysName = this.authSystemName;
        req.secret = new RSAUtil(this.GetPublicKey()).Encrypt(this.authSystemSecret);
        const result: TokenResult = this.restClient.Post<TokenResult>("auth/getToken", req);
        return result.accessToken;
    }

    private static GetPublicKey(): string {
        const para: { [key: string]: string } = {};
        para["sysName"] = this.authSystemName;
        return this.restClient.Get<string>("auth/getPublicKey", para);
    }

    public static GetRmAuthElementByMenu(menuCode: string, menuNo: string = "0"): ElementInfoResult {
        const para: { [key: string]: string } = {};
        para["menuCode"] = menuCode;
        para["menuNo"] = menuNo;
        return this.restClient.Get<ElementInfoResult>("client/getRmAuthElementByMenu", para, this.AuthToken);
    }

    public static ApplyRmAuth(applyInfoReq: ApplyInfoReq): string {
        return this.restClient.Post<string>("client/applyRmAuth", applyInfoReq, this.AuthToken);
    }

    public static GetRmAuthResultByRecord(rmAuthRecord: string): RmAuthResult {
        const para: { [key: string]: string } = {};
        para["rmAuthRecord"] = rmAuthRecord;
        return this.restClient.Get<RmAuthResult>("client/getRmAuthResultByRecord", para, this.AuthToken);
    }

    public static UndoRmAuth(rmAuthRecord: string): string {
        const para: { [key: string]: string } = {};
        para["rmAuthRecord"] = rmAuthRecord;
        return this.restClient.Get<string>("client/undoRmAuth", para, this.AuthToken);
    }

    public static UploadFile(fileName: string, fileByte: Uint8Array): string {
        let resultUploadeFile = "";
        try {
            const startime = new Date().toISOString().replace(/[^0-9]/g, '');
            PlatformLogger.SystemInfo(`--------------------------start--${startime}::${fileName}------------------------`);
            resultUploadeFile = this.restClient.UploadFile<string>("file/upload", fileName, fileByte, this.AuthToken);
        } catch (e) {
            // 原代码未处理异常，这里保持原样
        }
        const endtime = new Date().toISOString().replace(/[^0-9]/g, '');
        PlatformLogger.SystemInfo(`-----------------------end-----${endtime}::${resultUploadeFile}------------------------`);
        return resultUploadeFile;
    }

    public static UploadFileWithoutParams(): string {
        // 由于 Node.js 中文件操作和浏览器不同，这里只是模拟
        // 实际使用时需要正确实现文件读取逻辑
        // 以下代码仅为示例，无法直接运行
        // const filePath = "D:/pictrue/oYYBAFsfnJ-AI-bzAAAhtqb3L2s004.jpg";
        // const fileBuffer = fs.readFileSync(filePath);
        // return this.UploadFile("oYYBAFsfnJ-AI-bzAAAhtqb3L2s004.jpg", new Uint8Array(fileBuffer));
        throw new Error('需要实现文件读取逻辑');
    }

    public static GetFlawTradeList(): FlawTradeListResult[] {
        const para: { [key: string]: string } = {};
        para["userCode"] = this.tellerNo;
        return this.restClient.Get<FlawTradeListResult[]>("record/getFlawTradeList", para, this.AuthToken);
    }

    public static GetHistoryInfo(recordCode: string): AuthHistoryInfoResult {
        const para: { [key: string]: string } = {};
        para["recordCode"] = recordCode;
        return this.restClient.Get<AuthHistoryInfoResult>("/client/getHistoryInfo", para, this.AuthToken);
    }

    public static AdditionalRmauthInfo(flawInfoReq: FlawInfoReq): string {
        return this.restClient.Post<string>("record/additionalRmauthInfo", flawInfoReq, this.AuthToken);
    }
}